@@ -17,11 +17,11 @@ LocalTest - Test data and functions for L<Data::Validate::Type>.
 
 =head1 VERSION
 
-Version 1.4.3
+Version 1.5.0
 
 =cut
 
-our $VERSION = '1.4.3';
+our $VERSION = '1.5.0';
 
 
 =head1 SYNOPSIS
@@ -142,6 +142,14 @@ my $test_data =
 			[],
 		],
 	},
+	{
+		key         => 'regex',
+		data        => qr/test/,
+	},
+	{
+		key         => 'empty_regex',
+		data        => qr/test/,
+	},
 ];
 
 
